Module: ActiveJob::Notificare::StepDSL::ClassMethods
- Defined in:
- lib/active_job/notificare/step_dsl.rb
Instance Method Summary collapse
-
#has_step_notifications? ⇒ Boolean
True after the first run of any instance that called step(notify:).
Instance Method Details
#has_step_notifications? ⇒ Boolean
True after the first run of any instance that called step(notify:). Used by Recipient to enforce recipient: presence on subsequent enqueues.
21 22 23 |
# File 'lib/active_job/notificare/step_dsl.rb', line 21 def has_step_notifications? @_has_step_notifications == true end |